@@ -563,10 +563,11 @@ fn compare(expected: Option<&Path>, actual: &[u8], desc: &str) -> bool {
                 Ok(file) => file,
                 Err(e) => {
                     eprintln!(
-                        "failed to open {} file: {}\n\
+                        "failed to open {} file {:?}: {}\n\
                          -------- normalized actual {0} --------\n\
                          {}",
                         desc,
+                        expected,
                         e,
                         display_utf8_lossy(actual)
                     );
@@ -623,10 +624,16 @@ fn compare(expected: Option<&Path>, actual: &[u8], desc: &str) -> bool {
                          -------- stdout --------\n\
                          {}\
                          -------- stderr --------\n\
+                         {}\
+                         -------- normalized actual command {} \
+                                  (expected to match file {:?}) --------\n\
                          {}",
                         output.status,
                         display_utf8_lossy(&output.stdout),
-                        display_utf8_lossy(&output.stderr)
+                        display_utf8_lossy(&output.stderr),
+                        desc,
+                        expected,
+                        display_utf8_lossy(actual)
                     );
                 }
                 return false;
